# Liteblue

Another fine mess.

To install:
```
python3.8 -m venv venv
. venv/bin/activate
pip install liteblue
```

To create a project called calc:
```
liteblue create calc
```

To run the project:
```
docker-compose up
```

or:
```
liteblue run calc
```

Now point your browser at: [http://localhost:8080](http://localhost:8080)